@@ -1,5 +1,19 @@
 # Miscellaneous **non-exported** graph functions
 
+#' preprocess spatial columns of graph
+#'
+#' @noRd
+preprocess_spatial_cols <- function (graph) {
+
+    gr_cols <- dodgr_graph_cols (graph)
+    if (is.na (gr_cols$from) || is.na (gr_cols$to)) {
+        scols <- find_spatial_cols (graph)
+        graph$from_id <- scols$xy_id$xy_fr_id
+        graph$to_id <- scols$xy_id$xy_to_id
+    }
+    return (graph)
+}
+
 #' is_graph_spatial
 #'
 #' Is the graph spatial or not?
