@@ -219,9 +219,10 @@ set_maxspeed <- function (graph, wt_profile, wt_profile_file) {
     wp_index <- wp_index [graph_index]
     maxspeed <- cbind (graph$maxspeed, rep (NA, nrow (graph)))
     maxspeed [graph_index, 2] <- wp$max_speed [wp_index]
+
     if (wt_profile == "motorcar") {
         index <- which (is.na (maxspeed [, 1]))
-        graph$maxspeed [index] <- maxspeed [, 2]
+        graph$maxspeed [index] <- maxspeed [index, 2]
     } else {
         # choose minimal maxspeed value
         graph$maxspeed <- apply (maxspeed, 1, function (i) {
@@ -388,28 +389,36 @@ sc_traffic_lights <- function (graph, x, wt_profile, wt_profile_file) {
 rm_duplicated_edges <- function (graph) {
 
     gr_cols <- dodgr_graph_cols (graph)
-    ft <- graph [, c (gr_cols$from, gr_cols$to)]
-    index <- cbind (
-        which (duplicated (ft)),
-        which (duplicated (ft, fromLast = TRUE))
-    )
+    ft <- paste0 (graph [[gr_cols$from]], "-", graph [[gr_cols$to]])
+    ft_un <- unique (ft)
+    ft_dupl <- ft [which (duplicated (ft))]
+
+    # Get dual indices into ft of duplicate entries:
+    i1 <- match (ft_dupl, ft)
+    ft_mod <- ft
+    ft_mod [i1] <- paste0 (ft_mod [i1], "---")
+    i2 <- match (ft_dupl, ft_mod)
+
+    index <- cbind (i1, i2)
 
-    index <- cbind (
-        which (duplicated (graph [, c (".vx0", ".vx1")])),
-        which (duplicated (graph [, c (".vx0", ".vx1")], fromLast = TRUE))
-    )
     removes <- apply (index, 1, function (i) {
         ifelse (
-            graph$time [i [1]] > graph$time [i [2]],
+            graph [[gr_cols$d]] [i [1]] > graph [[gr_cols$d]] [i [2]],
             i [1],
             i [2]
         )
     })
-    graph [!seq_len (nrow (graph)) %in% removes, ]
+    if (length (removes) > 0L) {
+        graph <- graph [-removes, ]
+    }
+    return (graph)
 }
 
 # up to that point, all edges are non-duplicated, and so need to be duplicated
-# for non-oneway
+# for non-oneway. Note that strict accordance with oneway flags for "bicycle"
+# routing can generate unroutable networks. The following implements the more
+# realistic procedure of duplicting oneway edges for bicycle routing, but at
+# twice the weighted distance/time values.
 sc_duplicate_edges <- function (x, wt_profile) {
 
     oneway_modes <- c (
@@ -429,6 +438,19 @@ sc_duplicate_edges <- function (x, wt_profile) {
     xnew <- swap_cols (xnew, ".vx0_y", ".vx1_y")
     xnew$edge_ <- rcpp_gen_hash (nrow (xnew), 10)
 
+    if (wt_profile == "bicycle") {
+        index <- which (x$oneway)
+        xnew2 <- x [index, ]
+        xnew2 <- swap_cols (xnew2, ".vx0", ".vx1")
+        xnew2 <- swap_cols (xnew2, ".vx0_x", ".vx1_x")
+        xnew2 <- swap_cols (xnew2, ".vx0_y", ".vx1_y")
+        xnew2$edge_ <- rcpp_gen_hash (nrow (xnew2), 10)
+        xnew2$d_weighted <- xnew2$d * 2
+        xnew2$time_weighted <- xnew2$time * 2
+
+        xnew <- rbind (xnew, xnew2)
+    }
+
     res <- rbind (x, xnew)
     res$oneway <- NULL
 
